% menu item: free knots with NPSOL package

while 2
  clc
  choice1=menu('Free knots with NPSOL',...
      'Unconstrained approximation','Unconstrained smoothing','Quit');  
  
  if ((choice1<=0) | (choice1>=3))
    break
  end            
      
  if choice1==1                               % Unconstrained approximation
    method=1;
  elseif choice1==2                           % Unconstrained smoothing
    method=2;
  end % if choice1
  
  % set default values or empty matrices
  if ~exist('r1'), r1=2; end,
  if ~exist('r2'), r2=2; end,
  if ~exist('mu1'), mu1=0.0; end,
  if ~exist('mu2'), mu2=0.0; end, 
  
  % set up the independent variables (free knots)
  x=zeros(l1+l2,1);
  x(1:l1)=t1(pvec1);
  x(l1+1:l1+l2)=t2(pvec2);
       
  clc
  relative_constraints=readchar('Relative constraints (y/n)','y');
  if relative_constraints=='y'      
    [C1,h1]=relconst(n1,k1,t1,l1,pvec1,EPSILON1);
    [C2,h2]=relconst(n2,k2,t2,l2,pvec2,EPSILON2);
  else
    [C1,h1]=absconst(n1,k1,t1,l1,pvec1,EPSILON1);
    [C2,h2]=absconst(n2,k2,t2,l2,pvec2,EPSILON2);
  end 
  
  l=l1+l2;
  ncstr1=length(h1);
  ncstr2=length(h2);
  ncstr=ncstr1+ncstr2;
  C=zeros(ncstr,l);
  C(1:ncstr1,1:l1)=C1;
  C(ncstr1+1:ncstr1+ncstr2,l1+1:l1+l2)=C2; % direct sum of C1 and C2
  h=[h1;h2];
  low=-Inf.*ones(l+ncstr,1);
  up= Inf.*ones(l+ncstr,1);
  
  for i=1:ncstr,
    low(l+i)=h(i);
  end
  
  nofucall=0;
  
  DerLvl= 0;                    % derivative level          
  VerLvl= -1;                   % verify level
  PriLev= 2;                    % Print level
  optPar=zeros(30,1);           % optional parameters
  
  time1=cputime;
  x=npsol(x,low,up,C,'npfun','npcon',DerLvl,VerLvl,PriLev);
  time2=cputime-time1;
  t1(pvec1)=x(1:l1);
  t2(pvec2)=x(l1+1:l1+l2);  
  
  pause
  disp('Number of function evaluations:');
  disp(nofucall);
  disp('CPU-Time in seconds:');
  disp(time2);
      
  % compute function value
  
  if method==1                               % Unconstrained approximation
    [A,RES]=uncapp(m1, m2, n1, n2, k1, k2, t1, t2, x1, x2, Y);
  elseif method==2                           % Unconstrained smoothing
    [A,RES]=uncsmo(m1, m2, n1, n2, k1, k2, t1, t2, x1, x2, Y, r1, r2, mu1, mu2);
  end % if method 

  format long e
  disp('function value at solution point: ');
  disp(RES^2);
  disp('Norm of residual vector: ');
  disp(RES);
  disp('free knots at solution point (x-direction): ');
  disp(x(1:l1));
  disp('free knots at solution point (y-direction): ');
  disp(x(l1+1:l1+l2));
  format short
  pause
    
end % while 2