% menu item: plot
npoints=81; % number of points in each direction

% construct internal spline representation from knots and coefficients 
spl=spmak({t1',t2'},A);

xmin=readnum('X minimal',x1(1));
xmax=readnum('X maximal',x1(m1));
ymin=readnum('Y minimal',x2(1));
ymax=readnum('Y maximal',x2(m2)); % interval bounds for plot

xv=linspace(xmin,xmax,npoints);
yv=linspace(ymin,ymax,npoints); 

minxi=min(find((x1-xmin)>=0));
maxxi=max(find((xmax-x1)>=0));
minyi=min(find((x2-ymin)>=0));
maxyi=max(find((ymax-x2)>=0));

x1part=x1(minxi:maxxi);
x2part=x2(minyi:maxyi);
Ypart=Y(minxi:maxxi,minyi:maxyi);

while 2
  clc
  choice1=menu('Plot','Data','Approximant','Approximant with data',...
      'Derivative','Contour plot with knots','Residual',...
      'Print to file','Quit');  
  
  if ((choice1<=0) | (choice1>=8))
    break
  end    
  
  if choice1==1                               % Data
    figure
    mesh(x1,x2,Y.');
    axis([x1(1) x1(m1) x2(1) x2(m2) min(min(Y)) max(max(Y))]);
    title('Data');
  elseif choice1==2                           % Approximant
    points=fnval(spl,{xv,yv});
    figure
    mesh(xv,yv,points.');
    axis([xmin xmax ymin ymax min(min(points)) max(max(points))]);
    title('Tensor Product Spline Approximant')
  elseif choice1==3                           % Approximant with data
    points=fnval(spl,{xv,yv});
    figure
    mesh(xv,yv,points.');
    hold on
    h=mesh(x1part,x2part,Ypart.',zeros(size(Ypart.')));
    axis([xmin xmax ymin ymax min(min(points)) max(max(points))]);
    set(h,'FaceColor','none','Marker','*');
    title('Tensor Product Spline Approximant with Data')
    hold off
  elseif choice1==4                           % Derivative
    der1=readnum('Order of derivative in x-direction',1);
    der2=readnum('Order of derivative in y-direction',1);
    der=[der1 der2];
    points=fnval(fnder(spl,der),{xv,yv});
    figure
    mesh(xv,yv,points.');
    axis([xmin xmax ymin ymax min(min(points)) max(max(points))]);
    title('Derivative of Tensor Product Spline Approximant')
  elseif choice1==5                           % Contour plot with knots
    points=fnval(spl,{xv,yv});
    figure
    contour(xv,yv,points.');
    hold on
    for j=k1+1:n1,
      plot([t1(j) t1(j)],[ymin ymax],'y--');
    end
    for j=k2+1:n2,
      plot([xmin xmax],[t2(j) t2(j)],'y--');
    end
    title('Contour Plot of Tensor Product Spline Approximant')
    hold off
  elseif choice1==6                           % Residual
    residual=Y-fnval(spl,{x1,x2});
    figure
    mesh(x1,x2,residual.'); 
    axis([x1(1) x1(m1) x2(1) x2(m2) min(min(residual)) max(max(residual))])
    title('Residual of Tensor Product Spline Approximant')
  elseif choice1==7                           % Print to file
    no=readnum('Enter number of figure to print',1);
    figure(no)
    filename=readchar('Enter file name','figure.eps');
    color=readchar('Color plot (y/n)','n');
    if color=='y'
      print( '-depsc2', filename, gcf );
    else
      print( '-deps2', filename, gcf );
    end
  end % if choice1
end % while 2
close all
