% menu item: save

while 2,
  clc
  choice1=menu('Save','Data points','Spline parameter',...
      'Parameter','Quit');
 
  if ((choice1<=0) | (choice1>=4))
    break
  end
  
  if choice1==1                               % Data points
    
    % x1, x2 and Y will be saved to a file in the following format
    %
    %      0 |  x2^T
    %     ------------
    %        |
    %     x1 |   Y        ==> matrix of dimension (m1+1)*(m2+1)
    %        |
    
    clc
    Filename=uiputfile('*.m','Enter file name:');
    fid=fopen(Filename,'w');
        
    fprintf(fid,' %.14E',0.0);
    for j=1:m2,
      fprintf(fid,' %.14E',x2(j));
    end,                                      % 0 | x2^T
    fprintf(fid,'\n');
    for i=1:m1,
      fprintf(fid,' %.14E',x1(i));
      for j=1:m2,
        fprintf(fid,' %.14E',Y(i,j));
      end,
      fprintf(fid,'\n');
    end
    fclose(fid);
    
  elseif choice1==2                           % Spline parameter

    % t1, t2 and A will be saved to a file in the following format
    %
    %      0 |  t2^T
    %     -------------
    %        |     |  
    %     t1 |   A | 0      ==> matrix of dimension (n1+k1+1)*(n2+k2+1)
    %        |---------
    %        |   0 | 0
    %        |     |

    clc
    
    Filename=uiputfile('*.m','Enter file name:');
    fid=fopen(Filename,'w');
    
    fprintf(fid,' %.14E',0.0);
    for j=1:n2+k2,
      fprintf(fid,' %.14E',t2(j));
    end,
    fprintf(fid,'\n');                        % 0 | t2^T
    for i=1:n1,
      fprintf(fid,' %.14E',t1(i));
      for j=1:n2,
        fprintf(fid,' %.14E',A(i,j));
      end,
      for j=n2+1:n2+k2,
        fprintf(fid,' %.14E',0.0);
      end,
      fprintf(fid,'\n');
    end
    for i=n1+1:n1+k1,
      fprintf(fid,' %.14E',t1(i));
      for j=1:n2+k2,
        fprintf(fid,' %.14E',0.0);
      end,
      fprintf(fid,'\n');
    end
    fclose(fid);
     
  elseif choice1==3                           % Parameter      
    fprintf(1,'\nNumber of data points in x-direction m1= %4.0f\n',m1);
    fprintf(1,'Number of data points in y-direction m2= %4.0f\n',m2);
    fprintf(1,'Number of splines in x-direction n1= %4.0f\n',n1);
    fprintf(1,'Number of splines in y-direction n2= %4.0f\n',n2);
    fprintf(1,'Order of splines in x-direction k1= %4.0f\n',k1);
    fprintf(1,'Order of splines in y-direction k2= %4.0f\n',k2);
    fprintf(1,'Order of derivative in smoothing term (x-direction) r1= %4.0f\n',r1);
    fprintf(1,'Order of derivative in smoothing term (y-direction) r2= %4.0f\n',r2); 
    fprintf(1,'Smoothing parameter (x-direction) mu1= %25.12e\n',mu1);
    fprintf(1,'Smoothing parameter (y-direction) mu2= %25.12e\n',mu2);
    
    if exist('EPSILON1')
      fprintf(1,'Minimum distance between knots (x-direction) = %25.12e\n',EPSILON1); 
      fprintf(1,'Number of free knots (x-direction) l1= %4.0f\n',l1);
      fprintf(1,'Indices of free knots\n');
      for j=1:l1
        fprintf(1,'j= %4.0f; pvec1 = %4.0f\n',j,pvec1(j));
      end
    end
    if exist('EPSILON2')
      fprintf(1,'Minimum distance between knots (y-direction) = %25.12e\n',EPSILON2); 
      fprintf(1,'Number of free knots (y-direction) l2= %4.0f\n',l2);
      fprintf(1,'Indices of free knots\n');
      for j=1:l2
        fprintf(1,'j= %4.0f; pvec2 = %4.0f\n',j,pvec2(j));
      end
    end
 
  end  % if choice1
end % while 2
