function [A,RES,F]=uncapp(m1, m2, n1, n2, k1, k2, t1, t2, x1, x2, Y)
% function [A,RES,F]=uncapp(m1, m2, n1, n2, k1, k2, t1, t2, x1, x2, Y)
% unconstrained bivariate approximation
%
% compute coefficients of a polynomial tensor product spline of order k1 x k2
% in its B-spline representation to given knot sequence t1 x t2 which
% minimizes the least squares residual 
%
%  || Y - B1(t1) * A * B2(t2)^T ||_F^2
%
% for the data values Y_{i1,i2} and the abscissae (x1_i1, x2_i2)
% i1=1,...,m1; i2=1,...,m2
%
% Input:               m1;    number of data points in x-direction
%                      m2;    number of data points in y-direction
%                      n1;    number of B-splines in x-direction
%                      n2;    number of B-splines in y-direction
%                      k1;    order of B-Splines in x-direction
%                      k2;    order of B-Splines in y-direction
%            t1[1..n1+k1];    knot sequence in x-direction
%            t2[1..n2+k2];    knot sequence in y-direction
%               x1[1..m1];    data abszissae in x-direction
%               x2[1..m2];    data abszissae in y-direction
%          Y[1..m1,1..m2];    data values
%
% Output:  A[1..n1,1..n2];    coefficients of spline
%                     RES;    norm of residual matrix
%          F[1..m1,1..m2];    residual matrix

B1=spcol(t1',k1,x1');
B2=spcol(t2',k2,x2');

A=(B2\((B1\Y)'))';
F=Y-B1*A*B2';
RES=norm(F,'fro');
