function [C,h]=absconst(n, k, t, l, pvec, EPSILON)
% function [C, h]=absconst(n, k, t, l, pvec, EPSILON)
% absolute constraints
%
% compute matrix C and vector h for linear constraints g(t)=C*t-h >= 0
% which avoid the coalescing of knots for an absolute measure of distance
%
% Input:                n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                       l;    number of free knots
%              pvec[1..l];    index to free knots
%                 EPSILON;    absolute measure of distance
%
% Output: C[1..nrcol,1..l];    
%             h[1..nrcol];

% Generate matrix of constraints  t(i) < t(i+1)
if l==1
  C(1,1)=-1;
  C(2,1)= 1;
  h(1)=-t(pvec(1)-1)-EPSILON;
  h(2)=t(pvec(1)+1)-EPSILON;
else
  nrcol=1;
  C(nrcol,1)=-1;
  h(nrcol)=-t(pvec(1)-1)-EPSILON;
  nrcol=nrcol+1;
  if (pvec(1)+1==pvec(2))
    C(nrcol,1)=1;
    C(nrcol,2)=-1;
    h(nrcol)=-EPSILON;
  else
    C(nrcol,1)=1;
    h(nrcol)=t(pvec(1)+1)-EPSILON;
  end
  for j=2:l-1,
    if (pvec(j)-1==pvec(j-1))
      % nothing to do 
    else
      nrcol=nrcol+1;
      C(nrcol,j)=-1;
      h(nrcol)=-t(pvec(j)-1)-EPSILON;
    end
    nrcol=nrcol+1;
    if (pvec(j)+1==pvec(j+1))
      C(nrcol,j)=1;
      C(nrcol,j+1)=-1;
      h(nrcol)=-EPSILON;
    else
      C(nrcol,j)=1;
      h(nrcol)=t(pvec(j)+1)-EPSILON;
    end
  end

  % last knot
  if (pvec(l)-1==pvec(l-1))
    % nothing to do
  else
    nrcol=nrcol+1;
    C(nrcol,l)=-1;
    h(nrcol)=-t(pvec(l)-1)-EPSILON;
  end
  nrcol=nrcol+1;
  C(nrcol,l)=1;
  h(nrcol)=t(pvec(l)+1)-EPSILON;
end % if l==1
h=h(:); % return column vector
C=-C;
h=-h;