function D=deriv(t, n, k, r)
% function D=deriv(t, n, k, r)
% derivative matrix
%
% Computation of a matrix D, so that alpha^{r} = D_r alpha are the
% coefficients of the r-th order derivative of the given spline of order k
% with coefficients alpha belonging to the knotsequence t
%
% Input:         t[1..n+k];    knot sequence
%                        n;    number of B-Splines
%                        k;    order of B-Splines
%                        r;    order of derivative
% Output:  D[1..n-r][1..n];

if r==0
  D=eye(n,n);
else
  if any( t(k+1:n+k-r) == t(1+r:n) )
    error('deriv: Required derivative does not exist.');
  end; %if any
  for l=1:r
    H =  diag( (k-l) ./ ( t(k+1:n+k-l)-t(1+l:n)) );
    % D := H * L
    [mH,nH]= size(H);
    HL = [ -H(:,1), -H(:,2:nH)+H(:,1:nH-1), H(:,nH)];
    if l==1
      D = HL;
    else
      D = HL * D;
    end % if l==1
  end % for l=1:r
end % if r==0
