function S=smooth(t, n, k, r)
% function S=smooth(t, n, k, r)
% smoothing matrix
%
% Computation of a matrix S, so that \left\|  S \alpha \right|^2 is an upper
% bound for the smoothing term \int_a^b [ s^{r} (x)]^2 dx 
% 
% This approximation of the smoothing term results from replacing the L_2 -
% norm by its discrete equivalent l_2. 
% 
% \left\| S \alpha \right|^2 =
% \sum_{i=r+1}^{n} ( \alpha_i^{r} )^2 (t[i+k-r] - t[i]) / (k-r)
%  
% Input:        t[1..n+k];    knot sequence
%                       n;    number of B-Splines
%                       k;    order of B-Splines
%                       r;    order of derivative in smoothing term
% Output: S[1..n-r][1..n];

D=deriv(t,n,k,r);
F=diag(sqrt((t(k+1:n+k-r)-t(1+r:n))/(k-r)));
S=F*D;