function [alpha,RES,F]=conapp(m, n, k, t, x, y, p, L, U)
% function [alpha,RES,F]=conapp(m, n, k, t, x, y, p, L, U)
% constrained approximation
%
% compute coefficients of a polynomial spline of order k in its B-spline
% representation to given knot sequence t which minimizes the least squares
% residual 
%
%  || y - B(t) * alpha ||_2^2
%
% for the data points x[i], y[i] i=1,...,m
% under the shape constraints L <= alpha^p <= U
%
% Input:                m;    number of data points
%                       n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                 x[1..m];    data abszissae
%                 y[1..m];    data values
%                       p;    order of derivative in constraints
%               L[1..n-p];    lower bounds on alpha^p
%               U[1..n-p];    upper bounds on alpha^p
%
% Output:     alpha[1..n];    coefficients of spline
%                     RES;    norm of residual vector
%                 F[1..m];    residual vector 

B=spcol(t',k,x');
D=deriv(t,n,k,p);

A=[-D;D];
b=[-L;U];

OPTIONS=optimset('LargeScale','off','Display','off');
[alpha,tRES,tF]=lsqlin(B,y,A,b,[],[],[],[],[],OPTIONS);
RES=sqrt(tRES);
F=-tF;
