function [alpha,RES,F]=conappls(m, n, k, t, x, y, p, L, U)
% function [alpha,RES,F]=conappls(m, n, k, t, x, y, p, L, U)
% constrained approximation with LSSOL package
%
% compute coefficients of a polynomial spline of order k in its B-spline
% representation to given knot sequence t which minimizes the least squares
% residual 
%
%  || y - B(t) * alpha ||_2^2
%
% for the data points x[i], y[i] i=1,...,m
% under the shape constraints L <= alpha^p <= U
%
% Input:                m;    number of data points
%                       n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                 x[1..m];    data abszissae
%                 y[1..m];    data values
%                       p;    order of derivative in constraints
%               L[1..n-p];    lower bounds on alpha^p
%               U[1..n-p];    upper bounds on alpha^p
%
%                             On output y will be overwritten! If you
%                             don't want this, you should call
%
%                             ysave=y+0;
%                             [alpha,RES]=conappls(m,n,k,t,x,y,p,L,U);
%                             y=ysave;   
%
%                             to avoid a bug in Matlab!
%
% Output:     alpha[1..n];    coefficients of spline
%                     RES;    norm of residual vector
%                 F[1..m];    residual vector

B=spcol(t',k,x');
D=deriv(t,n,k,p);

c=zeros(n,1);
l=-inf.*ones(n+n-p,1);
u= inf.*ones(n+n-p,1);
l(n+1:2*n-p)=L;
u(n+1:2*n-p)=U;
alpha0=zeros(n,1);
F=y;
[alpha,obj]=lssol(B,y,c,D,alpha0,l,u,'ls1',0);
RES=sqrt(2*obj);
F=F-B*alpha;