function [L,U]=inpbound(m, n, k, t, x, p)
% function [L,U]=inpbound(m, n, k, t, x, p)
% input bounds
%
% input bounds on derivatives
%
%    l_i <= s^(p) (x) <= u_i  for all x in [t_i,t_{i+1}), i=k,..,n
%
% l_i, u_i i=1,..,k-1 arbitrary
%
% and transform them into bounds on coefficients
%
%    L_j <= alpha^(p)_j  <= U_j  j=p+1,..,n
%
% Input:                m;    number of data points
%                       n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                 x[1..m];    data abszissae
%                       p;    order of derivative in constraints
%
% Output:       L[1..n-p];    lower bounds on alpha^(p)
%               U[1..n-p];    upper bounds on alpha^(p)
 
% default: no constraints
l=-inf.*ones(n,1);
u=inf.*ones(n,1);

y_lower=0;
interval_min=t(k);
interval_max=t(n+1); % assume constraint is imposed on whole interval

clc

ch=readchar('Impose lower bounds (y/n)','y');
if upper(ch)=='Y'
  loop=1;
else
  loop=0;
end

while loop==1,
  interval_min=readnum('From (left interval bound)',interval_min);
  left_min=sorted(t,interval_min);
  % interval(interval_min,n+1,t,left_min,out_of_interval);
  left_min=readnum('From left knot index',left_min);

  interval_max=readnum('To (right interval bound)',interval_max);
  left_max=sorted(t,interval_max);
  % interval(interval_max,n+1,t,left_max,out_of_interval);
  if interval_max >= t(n+1)
    left_max=n+1;
  end
  left_max=readnum('To right knot index',left_max);

  ch=readchar('Impose lower bound (y/n)','y');
  if upper(ch)=='Y' 
    y_lower=readnum('Value of lower bound',y_lower);
    for i=left_min:left_max-1
      l(i)=y_lower;
    end
  end   
  
  if left_max <= n
    ch=readchar('Another interval with lower bounds? (y/n)','y');
    if upper(ch)=='Y'
      loop=1;
    else
      loop=0;
    end
  else
    loop=0;
  end    
  
  interval_min= t(left_max);
  interval_max= t(n+1);
end % while loop

y_upper=0;
interval_min=t(k);
interval_max=t(n+1); % assume constraint is imposed on whole interval

clc

ch=readchar('Impose upper bounds (y/n)','y');
if upper(ch)=='Y'
  loop=1;
else
  loop=0;
end

while loop==1,
  interval_min=readnum('From (left interval bound)',interval_min);
  left_min=sorted(t,interval_min);
  % interval(interval_min,n+1,t,left_min,out_of_interval);
  left_min=readnum('From left knot index',left_min);

  interval_max=readnum('To (right interval bound)',interval_max);
  left_max=sorted(t,interval_max);
  % interval(interval_max,n+1,t,left_max,out_of_interval);
  if interval_max >= t(n+1)
    left_max=n+1;
  end
  left_max=readnum('To right knot index',left_max);

  ch=readchar('Impose upper bound (y/n)','y');
  if upper(ch)=='Y' 
    y_upper=readnum('Value of upper bound',y_upper);
    for i=left_min:left_max-1
      u(i)=y_upper;
    end
  end   
  
  if left_max <= n
    ch=readchar('Another interval with upper bounds? (y/n)','y');
    if upper(ch)=='Y'
      loop=1;
    else
      loop=0;
    end
  else
    loop=0;
  end    
  
  interval_min= t(left_max);
  interval_max= t(n+1);
end % while loop

[L,U]=trbound(n, k, p, l, u);
