% menu item: free knots with NPSOL package

while 2
  clc
  choice1=menu('Free knots with NPSOL',...
      'Unconstrained approximation','Unconstrained smoothing',...
      'Constrained approximation','Constrained smoothing','Quit');  
  
  if ((choice1<=0) | (choice1>=5))
    break
  end            
      
  if choice1==1                               % Unconstrained approximation
    method=1;
  elseif choice1==2                           % Unconstrained smoothing
    method=2;
  elseif choice1==3                           % Constrained approximation
    method=3;  
  elseif choice1==4                           % Constrained smoothing
    method=4;  
  end % if choice1
  
  % set default values or empty matrices
  if ~exist('r'), r=2; end,
  if ~exist('mu'), mu=0.0; end,
  if ~exist('p'), p=2; end,
  if ~exist('L'), L=[]; end,
  if ~exist('U'), U=[]; end,
  
  % set up the independent variables (free knots)
  ttilde=zeros(l,1);
  ttilde=t(pvec);
       
  clc
  relative_constraints=readchar('Relative constraints (y/n)','y');
  if relative_constraints=='y'      
    [C,h]=relconst(n,k,t,l,pvec,EPSILON);
  else
    [C,h]=absconst(n,k,t,l,pvec,EPSILON);
  end
  
  low=-Inf.*ones(l+length(h),1);
  up= Inf.*ones(l+length(h),1);
  
  for i=1:length(h),
    low(l+i)=h(i);
  end

  nofucall=0;
  
  DerLvl= 0;                    % derivative level          
  VerLvl= -1;                   % verify level
  PriLev= 2;                    % Print level
  optPar=zeros(30,1);           % optional parameters
  
  time1=cputime;
  ttilde=npsol(ttilde,low,up,C,'npfun','npcon',DerLvl,VerLvl,PriLev); 
  time2=cputime-time1; 
  t(pvec)=ttilde;
  
  pause
  disp('Number of function evaluations:');
  disp(nofucall);
  disp('CPU-Time in seconds:');
  disp(time2);
      
  % compute function value
  
  if method==1                               % Unconstrained approximation
    [alpha,RES]=uncapp(m,n,k,t,x,y);
  elseif method==2                           % Unconstrained smoothing
    [alpha,RES]=uncsmo(m,n,k,t,x,y,r,mu);
  elseif method==3                           % Constrained approximation
    [alpha,RES]=conapp(m,n,k,t,x,y,p,L,U);  
  elseif method==4                           % Constrained smoothing
    [alpha,RES]=consmo(m,n,k,t,x,y,r,mu,p,L,U);  
  end % if method 

  format long e
  disp('function value at solution point: ');
  disp(RES^2);
  disp('Norm of residual vector: ');
  disp(RES);
  disp('free knots at solution point: ');
  disp(ttilde);
  format short
  pause
    
end % while 2

