function [L,U]=trbound(n, k, p, l, u)
% function [L,U]=trbound(n, k, p, l, u)
% transform bounds
%
% transform bounds on derivatives
%
%    l_i <= s^(p) (x) <= u_i  for all x in [t_i,t_{i+1}), i=k,..,n
%
% l_i, u_i i=1,..,k-1 arbitrary
%
% in bounds on coefficients
%
%    L_j <= alpha^(p)_j  <= U_j  j=p+1,..,n
%
% Input:                n;    number of B-splines
%                       k;    order of B-Splines
%                       p;    order of derivative in constraints
%                 l[1..n];    lower bounds on s^(p) (x)
%                 u[1..n];    upper bounds on s^(p) (x)
%
% Output:       L[1..n-p];    lower bounds on alpha^(p)
%               U[1..n-p];    upper bounds on alpha^(p)

L=zeros(n-p,1);
U=zeros(n-p,1);

for j=p+1:n,
  imin=max(j,k);
  imax=min(j+k-p-1,n); % index set W_j={imin,...,imax}
  
  L(j-p)=min(l(imin:imax));
  U(j-p)=max(u(imin:imax));
end
