function [alpha,RES,F]=uncapp(m, n, k, t, x, y)
% function [alpha,RES,F]=uncapp(m, n, k, t, x, y)
% unconstrained approximation
%
% compute coefficients of a polynomial spline of order k in its B-spline
% representation to given knot sequence t which minimizes the least squares
% residual 
%
%  || y - B(t) * alpha ||_2^2
%
% for the data points x[i], y[i] i=1,...,m
%
% Input:                m;    number of data points
%                       n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                 x[1..m];    data abszissae
%                 y[1..m];    data values
%
% Output:     alpha[1..n];    coefficients of spline
%                     RES;    norm of residual vector
%                 F[1..m];    residual vector

B=spcol(t',k,x');

alpha=B\y;
F=y-B*alpha;
RES=norm(F,2);

