function [alpha,RES,F]=uncappls(m, n, k, t, x, y)
% function [alpha,RES]=uncappls(m, n, k, t, x, y)
% unconstrained approximation with LSSOL package
%
% compute coefficients of a polynomial spline of order k in its B-spline
% representation to given knot sequence t which minimizes the least squares
% residual 
%
%  || y - B(t) * alpha ||_2^2
%
% for the data points x[i], y[i] i=1,...,m
%
% Input:                m;    number of data points
%                       n;    number of B-splines
%                       k;    order of B-Splines
%               t[1..n+k];    knot sequence
%                 x[1..m];    data abszissae
%                 y[1..m];    data values
%
%                             On output y will be overwritten! If you
%                             don't want this, you should call
%
%                             ysave=y+0;
%                             [alpha,RES]=uncappls(m,n,k,t,x,y);
%                             y=ysave;   
%
%                             to avoid a bug in Matlab!
%
% Output:     alpha[1..n];    coefficients of spline
%                     RES;    norm of residual vector
%                 F[1..m];    residual vector

B=spcol(t',k,x');

c=zeros(n,1);
A=zeros(1,n);
l=-inf.*ones(n+1,1);
u= inf.*ones(n+1,1);
alpha0=zeros(n,1);
F=y;
[alpha,obj]=lssol(B,y,c,A,alpha0,l,u,'ls1',0);
RES=sqrt(2*obj);
F=F-B*alpha;
